==> multisite_manager_tool-1.0.4.tar.gz: multisite_manager_tool/src/SitesHelper.php <==
<?php

declare(strict_types=1);

namespace Drupal\multisite_manager_tool;

use Drupal\Core\Database\Connection;
use Drupal\Core\Database\DatabaseExceptionWrapper;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a helper for multisite system.
 */
class SitesHelper implements ContainerInjectionInterface {

  /**
   * Logger Factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactoryInterface
   */
  protected $loggerFactory;

  /**
   * Database Service Object.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * Inject Services.
   *
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger factory.
   * @param \Drupal\Core\Database\Connection $database
   *   The database connection.
   */
  public function __construct(LoggerChannelFactoryInterface $logger_factory, Connection $database) {
    $this->loggerFactory = $logger_factory;
    $this->database = $database;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('logger.factory'),
      $container->get('database')
    );
  }

  /**
   * Sites directory Drupal.
   */
  const SITES_DIRECTORY = DRUPAL_ROOT . "/sites/";

  /**
   * Get the list of available multisites.
   */
  public static function getMultisiteList():array {
    $sites_directory = self::SITES_DIRECTORY;
    $sites = [];

    foreach (scandir($sites_directory) as $folder) {
      if ($folder === '.' || $folder === '..' || in_array($folder, ['default', 'all'])) {
        // Ignore some sites.
        continue;
      }
      if (is_dir("$sites_directory$folder") && file_exists("$sites_directory$folder/settings.php")) {
        $sites[$folder] = $folder;
      }
    }

    return $sites;
  }

  /**
   * Check if exist at least one site.
   */
  public function checkIfOneSite():bool {
    return (count($this->getMultisiteList()) > 0);
  }

  /**
   * Check if already site exist.
   *
   * @param string $site_name
   *   The site name.
   */
  public function checkIfExist($site_name):bool {
    $site_list = self::getMultisiteList();
    $site_list['default'] = 'default';

    if (in_array($site_name, $site_list)) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * Check if already databas name exist.
   *
   * @param string $name
   *   The site name.
   * @param bool $prefix
   *   Check tables prefix.
   */
  public function checkIfDbExist($name, $prefix = FALSE):null|bool {
    try {
      if (!$prefix) {
        $exists = $this->database
          ->query("SELECT SCHEMA_NAME FROM INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_NAME = :name", [':name' => $name])
          ->fetchField();
        return (bool) $exists;
      }
      else {
        $results = $this->database->schema()->findTables($name . '%');
        return !empty($results);
      }

      return FALSE;
    }
    catch (DatabaseExceptionWrapper $e) {
      $this->loggerFactory->get("multisite_manager_tool")->error('Error in query: ' . $e->getMessage());
      return NULL;
    }
  }

  /**
   * Execute drush command per site.
   *
   * @param string $site
   *   The site.
   * @param string $command
   *   The command to be executed.
   */
  public function drushCommandSite(string $site, string $command):void {
    $command = "drush --root=" . escapeshellarg(DRUPAL_ROOT) . " --uri=" . escapeshellarg($site) . " " . escapeshellarg($command);
    exec($command, $output, $return_var);
  }

}

==> multisite_manager_tool-1.0.6.tar.gz: multisite_manager_tool/src/SitesHelper.php <==
<?php

declare(strict_types=1);

namespace Drupal\multisite_manager_tool;

use Drupal\Core\Database\Connection;
use Drupal\Core\Database\DatabaseExceptionWrapper;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a helper for multisite system.
 */
class SitesHelper implements ContainerInjectionInterface {

  /**
   * Logger Factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactoryInterface
   */
  protected $loggerFactory;

  /**
   * Database Service Object.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  public function __construct(LoggerChannelFactoryInterface $logger_factory, Connection $database) {
    $this->loggerFactory = $logger_factory;
    $this->database = $database;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('logger.factory'),
      $container->get('database')
    );
  }

  /**
   * Sites directory Drupal.
   */
  const SITES_DIRECTORY = DRUPAL_ROOT . "/sites/";

  /**
   * Get the list of available sites.
   */
  public static function getMultisiteList():array {
    $sites_directory = self::SITES_DIRECTORY;
    $sites = [];

    foreach (scandir($sites_directory) as $folder) {
      if ($folder === '.' || $folder === '..' || in_array($folder, ['default', 'all'])) {
        // Ignore some sites.
        continue;
      }
      if (is_dir("$sites_directory$folder") && file_exists("$sites_directory$folder/settings.php")) {
        $sites[$folder] = $folder;
      }
    }

    return $sites;
  }

  /**
   * Check if exist at least one site.
   */
  public function checkIfOneSite():bool {
    return (count($this->getMultisiteList()) > 0);
  }

  /**
   * Check if already site exist.
   *
   * @param string $site_name
   *   The site name.
   */
  public function checkIfExist($site_name):bool {
    $site_list = self::getMultisiteList();
    $site_list['default'] = 'default';

    if (in_array($site_name, $site_list)) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * Check if already database name exist.
   *
   * @param string $name
   *   The site name.
   * @param bool $prefix
   *   Check tables prefix.
   */
  public function checkIfDbExist($name, $prefix = FALSE):null|bool {
    try {
      if (!$prefix) {
        $exists = $this->database
          ->query("SELECT SCHEMA_NAME FROM INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_NAME = :name", [':name' => $name])
          ->fetchField();
        return (bool) $exists;
      }
      else {
        $results = $this->database->schema()->findTables($name . '%');
        return !empty($results);
      }

      return FALSE;
    }
    catch (DatabaseExceptionWrapper $e) {
      $this->loggerFactory->get("multisite_manager_tool")->error('Error in query: ' . $e->getMessage());
      return NULL;
    }
  }

  /**
   * Execute drush command per site.
   *
   * @param string $site
   *   The site.
   * @param string $command
   *   The command to be executed.
   */
  public function drushCommandSite(string $site, string $command):void {
    $command = "drush --root=" . escapeshellarg(DRUPAL_ROOT) . " --uri=" . escapeshellarg($site) . " " . escapeshellarg($command);
    exec($command, $output, $return_var);
  }

}
